import json
from django.core.management.base import CommandParser
from jutil.command import SafeCommand
from jutil.request import get_geo_ip


class Command(SafeCommand):
    help = "Gets info about IP address"

    def add_arguments(self, parser: CommandParser):
        parser.add_argument("ip", type=str)

    def do(self, *args, **kw):
        data = get_geo_ip(kw["ip"])
        self.stdout.write(json.dumps(data, indent=4))



import requests
from django.conf import settings
from jutil.validators import phone_filter


def send_sms(phone: str, message: str, sender: str = "", **kw):
    """
    Sends SMS via Kajala Group SMS API. Contact info@kajala.com for access.
    :param phone: Phone number
    :param message: Message to be esnd
    :param sender: Sender (max 11 characters)
    :param kw: Variable key-value pairs to be sent to SMS API
    :return: Response from requests.post
    """
    if not hasattr(settings, "SMS_TOKEN"):
        raise Exception("Invalid configuration: settings.SMS_TOKEN missing")
    if not sender:
        sender = settings.SMS_SENDER_NAME
    if not sender:
        raise Exception("Invalid configuration: settings.SMS_SENDER_NAME missing")
    headers = {
        "Content-Type": "application/json",
        "Authorization": "Token " + settings.SMS_TOKEN,
    }
    data = {
        "dst": phone_filter(phone),
        "msg": message,
        "src": sender,
    }
    for k, v in kw.items():
        data[k] = v
    return requests.post("https://sms.kajala.com/api/sms/", json=data, headers=headers)



from django.utils.formats import date_format


def formatted_date(short_description=None, admin_order_field=None, fmt: str = "SHORT_DATE_FORMAT"):
    """
    Decorator for formatting date/datetime field in Django admin.
    :param short_description: Short description of the function (default is "short date").
    :param admin_order_field: Admin order field (optional).
    :param fmt: Format to pass to date_format (default "SHORT_DATE_FORMAT")

    Usage example in Django Admin:

    @date_format_short_date(_("timestamp"), "timestamp")
    def timestamp_short(obj):
        return obj.timestamp
    """

    def wrap_func(func):
        def short_date(*args, **kwargs):
            val = func(*args, **kwargs)
            if not val:
                return ""
            return date_format(val, fmt)

        if short_description is not None:
            short_date.short_description = short_description
        if admin_order_field is not None:
            short_date.admin_order_field = admin_order_field
        return short_date

    return wrap_func
